@@ -42,9 +42,9 @@
 #include <csignal>
 #include <unistd.h>
 
+QFile logFile;
 QString current_kernel;
 extern const QString starting_home = qEnvironmentVariable("HOME");
-static QFile logFile;
 static QTranslator qtTran, qtBaseTran, appTran;
 
 void checkSquashfs();
@@ -56,7 +56,10 @@ void signalHandler(int signal);
 
 int main(int argc, char *argv[])
 {
-    qputenv("XDG_RUNTIME_DIR", "/run/user/0");
+    if (getuid() == 0) {
+        qputenv("XDG_RUNTIME_DIR", "/run/user/0");
+        qunsetenv("SESSION_MANAGER");
+    }
     signal(SIGINT, signalHandler);
     signal(SIGTERM, signalHandler);
     signal(SIGHUP, signalHandler);
@@ -88,6 +91,7 @@ int main(int argc, char *argv[])
                       QObject::tr("Use the option one time for each item you want to exclude"), QObject::tr("one item")});
     parser.addOption({{"z", "compression"}, QObject::tr("Compression format, valid choices: ")
                       + "lz4, lzo, gzip, xz, zstd", QObject::tr("format")});
+    parser.addOption({"shutdown", QObject::tr("Shutdown computer when done.")});
 
     QStringList opts;
     opts.reserve(argc);
@@ -124,6 +128,7 @@ int main(int argc, char *argv[])
         setTranslation();
         checkSquashfs();
         if (getuid() == 0) {
+            qputenv("HOME", "/root");
             setLog();
             qDebug().noquote() << qApp->applicationName() << QObject::tr("version:") << qApp->applicationVersion();
             if (argc > 1) qDebug().noquote() << "Args:" << qApp->arguments();
@@ -150,10 +155,10 @@ int main(int argc, char *argv[])
         }
 
         if (getuid() == 0) {
+            qputenv("HOME", "/root");
             setLog();
             qDebug().noquote() << qApp->applicationName() << QObject::tr("version:") << qApp->applicationVersion();
             if (argc > 1) qDebug().noquote() << "Args:" << qApp->arguments();
-            qputenv("HOME", "/root");
             MainWindow w(nullptr, parser);
             w.show();
             exit(QApplication::exec());
